@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20190920';
+our $VERSION = '5.20191020';
 our %utilities;
 
 sub utilities {
@@ -1537,6 +1537,13 @@ my %delta = (
         removed => {
         }
     },
+    5.031005 => {
+        delta_from => 5.031004,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
